import pandas as pd
import unittest

from easyexplore.data_explorer import DataExplorer

DATA_SET: pd.DataFrame = pd.read_csv(filepath_or_buffer='test_data.csv', sep=',')
TEXT_DATA: pd.DataFrame = pd.read_csv(filepath_or_buffer='amazon_musical_instruments_reviews.csv')


class DataExplorerTest(unittest.TestCase):
    """
    Unit test for class DataExplorer
    """
    def test_break_down(self):
        self.assertEqual(first=0.49000000000000005,
                         second=DataExplorer(df=DATA_SET, plot=False).break_down()['continuous']['J']['de']['C'].get('mean')
                         )

    def test_cor(self):
        pass

    def test_data_distribution(self):
        _data_distribution: dict = DataExplorer(df=DATA_SET, plot=False).data_distribution()
        _sample_results: dict = dict(F=_data_distribution['F'].get('Hamburg'), C=_data_distribution['C'].get('mean'))
        self.assertDictEqual(d1=dict(F=4, C=0.49000000000000005),
                             d2=_sample_results
                             )

    def test_data_health_check(self):
        self.assertDictEqual(d1={'cases': [], 'features': ['J', 'K']},
                             d2=DataExplorer(df=DATA_SET, plot=False).data_health_check()
                             )

    def test_data_typing(self):
        self.assertDictEqual(d1={'B': 'int', 'D': 'datetime', 'F': 'int', 'I': 'int', 'J': 'int', 'K': 'int'},
                             d2=DataExplorer(df=DATA_SET, plot=False).data_typing()
                             )

    def test_get_feature_types(self):
        self.assertDictEqual(d1={'continuous': ['C', 'G', 'H'],
                                 'categorical': ['A', 'B', 'F', 'I', 'J', 'K'],
                                 'ordinal': [],
                                 'date': ['D'],
                                 'text': ['E']
                                 },
                             d2=DataExplorer(df=DATA_SET, plot=False).get_feature_types()
                             )

    def test_geo_stats(self):
        pass

    def test_outlier_detector(self):
        pass

    def test_text_analyzer(self):
        self.assertTrue(expr=DataExplorer(df=TEXT_DATA).text_analyzer(lang='en').shape[1] > 0)


if __name__ == '__main__':
    unittest.main()



import pandas as pd
import unittest

from easyexplore.data_explorer import DataExplorer
from easyexplore.text_miner import TextMiner

DATA_SET: pd.DataFrame = pd.read_csv(filepath_or_buffer='amazon_musical_instruments_reviews.csv')
ID_TEXT: dict = DataExplorer(df=DATA_SET).get_feature_types()
TEXT_MINER: TextMiner = TextMiner(df=DATA_SET,
                                  features=ID_TEXT.get('id_text'),
                                  lang='en',
                                  auto_interpret_natural_language=True
                                  )


class TextMinerTest(unittest.TestCase):
    """
    Unit test for class TextMiner
    """
    def test_clustering(self):
        pass

    def test_detect_lang(self):
        _lang_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_lang'))
        TEXT_MINER.detect_lang(sampling=True)
        self.assertTrue(expr=_lang_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_lang')) > 0)

    def test_emoji_handler(self):
        _emoji_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_emojis'))
        TEXT_MINER.emoji_handler()
        self.assertTrue(expr=_emoji_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_emojis')) > 0)

    def test_find_occurances(self):
        _occurance_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_MONEY'))
        TEXT_MINER.count_occurances(features=['reviewText'], search_text='_MONEY')
        self.assertTrue(expr=_occurance_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_MONEY')) > 0)

    def test_generate_linguistic_features(self):
        _ner_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_ner_'))
        _pos_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_pos_'))
        TEXT_MINER.generate_linguistic_features()
        self.assertTrue(expr=_ner_feature == 0 and _pos_feature == 0 and (len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_ner')) > 0) and (len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_pos')) > 0))

    def test_get_generated_features(self):
        self.assertTrue(expr=TEXT_MINER.get_generated_features().shape[1] > 0)

    def test_get_str_match(self):
        self.assertTrue(expr=len(TEXT_MINER.get_str_match(cases=['abc', 'def'], substring='b')) > 0)

    def test_merge(self):
        _merge_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_merge_'))
        TEXT_MINER.merge(features=['reviewText', 'summary'])
        self.assertTrue(expr=_merge_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_merge_')) > 0)

    def test_replace(self):
        TEXT_MINER.replace(features=['summary'], find_values=['MONEY'], replace_value='Gianni')
        TEXT_MINER.count_occurances(features=['summary'], search_text='Gianni')
        self.assertTrue(expr=len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='summary_Gianni')) > 0)

    def test_splitter(self):
        _split_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_split_'))
        TEXT_MINER.splitter(features=['reviewText'], sep=' ')
        self.assertTrue(expr=_split_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_split_')) > 0)

    def test_segmentation(self):
        self.assertDictEqual(d1={'enumeration': [],
                                 'phrases': ['reviewerName', 'reviewText', 'summary'],
                                 'id': [],
                                 'email': [],
                                 'rating': [],
                                 'url': [],
                                 'unknown': ['reviewerID', 'asin']
                                 },
                             d2=TEXT_MINER.segments
                             )

    def test_similarity(self):
        _similarity_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_similarity'))
        TEXT_MINER.similarity()
        self.assertTrue(expr=_similarity_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_similarity')) > 0)

    def test_tfifd(self):
        _tfidf_feature: int = len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_tfidf'))
        TEXT_MINER.tfidf()
        self.assertTrue(expr=_tfidf_feature == 0 and len(TEXT_MINER.get_str_match(cases=list(TEXT_MINER.df.keys()), substring='_tfidf')) > 0)

    def test_translate(self):
        self.assertEqual(first='ciao', second=TEXT_MINER.translate(text='hallo', lang='it').lower())


if __name__ == '__main__':
    unittest.main()



import plotly.graph_objs as go
import unittest

from easyexplore.interactive_visualizer import PlotlyAdapter

PLOT: dict = dict(df=None, kwargs={})


class PlotlyAdapterTest(unittest.TestCase):
    """
    Unit test for class PlotlyAdapter
    """
    def test_bar(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).bar(), go.Bar))

    def test_barpolar(self):
        pass

    def test_box_whisker(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).box_whisker(), go.Box))

    def test_candlestick(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).candlestick(), go.Candlestick))

    def test_choroplethmapbox(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).choroplethmapbox(), go.Choroplethmapbox))

    def test_contour(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).contour(), go.Contour))

    def test_mesh_3d(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).mesh_3d(), go.Mesh3d))

    def test_dendrogram(self):
        pass

    def test_densitymapbox(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).densitymapbox(), go.Densitymapbox))

    def test_distplot(self):
        pass

    def test_funnel(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).funnel(), go.Funnel))

    def test_funnel_area(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).funnel_area(), go.Funnelarea))

    def test_generate_subplots(self):
        pass

    def test_heat_map(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).heat_map(), go.Heatmap))

    def test_heat_map_annotated(self):
        pass

    def test_histo(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).histo(), go.Histogram))

    def test_histo_2d_contour(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).histogram_2d_contour(), go.Histogram2dContour))

    def test_line(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).line(), go.Scatter))

    def test_load(self):
        pass

    def test_parallel_category(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).parallel_category(), go.Parcats))

    def test_parallel_coordinates(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).parallel_coordinates(), go.Parcoords))

    def test_pie(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).pie(), go.Pie))

    def test_ridgeline(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).ridgeline(), go.Violin))

    def test_render(self):
        pass

    def test_save(self):
        pass

    def test_scatter(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).scatter(), go.Scatter))

    def test_scatter3d(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).scatter3d(), go.Scatter3d))

    def test_scatter_gl(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).scatter_gl(), go.Scattergl))

    def test_scatter_geo(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).scatter_geo(), go.Scattergeo))

    def test_scatter_mapbox(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).scatter_mapbox(), go.Scattermapbox))

    def test_show_plotly_offline(self):
        pass

    def test_subplots(self):
        pass

    def test_sunburst(self):
        pass

    def test_table(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).table(), go.Table))

    def test_treemap(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).treemap(), go.Treemap))

    def test_violin(self):
        self.assertTrue(expr=isinstance(PlotlyAdapter(plot=PLOT).violin(), go.Violin))


if __name__ == '__main__':
    unittest.main()



import setuptools
import subprocess
import sys

# Install complete dask library for handling big data sets using parallel computing:
subprocess.run(['python{} -m pip install "dask[distributed]"'.format('3' if sys.platform.find('win') != 0 else '')], shell=True)
subprocess.run(['python{} -m pip install "dask[complete]"'.format('3' if sys.platform.find('win') != 0 else '')], shell=True)

# Install jupyter notebook extensions for using EasyExplore_examples.ipynb more conveniently:
subprocess.run(['python{} -m pip install jupyter_contrib_nbextensions && jupyter contrib nbextension install'.format('3' if sys.platform.find('win') != 0 else '')], shell=True)

with open('README.md', 'r') as _read_me:
    long_description = _read_me.read()

with open('requirements.txt', 'r') as _requirements:
    requires = _requirements.read()

requires = [r.strip() for r in requires.split('\n') if ((r.strip()[0] != "#") and (len(r.strip()) > 3) and "-e git://" not in r)]

setuptools.setup(
    name='easyexplore',
    version='0.6.0',
    author='Gianni Francesco Balistreri',
    author_email='gbalistreri@gmx.de',
    description='Toolbox for easy and effective data exploration',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords='data exploration interactive visualization machine learning plotly',
    license='GNU',
    url='https://github.com/GianniBalistreri/easyexplore',
    include_package_data=True,
    packages=setuptools.find_packages(),
    package_data={'easyexplore': ['LICENSE',
                                  'README.md',
                                  'requirements.txt',
                                  'setup.py',
                                  'EasyExplore_examples.ipynb'
                                  ]
                  },
    data_file=[('test', ['test/test_anomaly_detector.py',
                         'test/test_data.csv',
                         'test/test_data_explorer.py',
                         'test/test_data_import_export.py',
                         'test/test_data_visualizer.py',
                         'test/test_interactive_visualizer.py',
                         #'test/test_text_miner.py',
                         'test/test_utils.py'
                         ]
                )],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=requires
)



import os
import pandas as pd
import unittest

from easyexplore.data_visualizer import DataVisualizer

DATA_SET: pd.DataFrame = pd.read_csv(filepath_or_buffer='test_data.csv', sep=',')


class DataVisualizerTest(unittest.TestCase):
    """
    Unit test for class DataVisualizer
    """
    def test_load(self):
        pass

    def test_run(self):
        DataVisualizer(title='DataVisualizer Test',
                       df=DATA_SET,
                       features=['F'],
                       plot_type='pie',
                       render=False,
                       file_path='test_data_visualizer.html'
                       ).run()
        self.assertTrue(expr=os.path.isfile('test_data_visualizer.html'))


if __name__ == '__main__':
    unittest.main()
